@@ -1,7 +1,7 @@
 module OrdinaryDiffEqFeagin
 
 import OrdinaryDiffEqCore: alg_order, calculate_residuals!,
-                           initialize!, perform_step!, @unpack, unwrap_alg,
+                           initialize!, perform_step!, unwrap_alg,
                            calculate_residuals,
                            OrdinaryDiffEqAlgorithm,
                            OrdinaryDiffEqMutableCache, OrdinaryDiffEqConstantCache,
